Class: Factorix::CLI::Commands::Version

Inherits:
Base
  • Object
show all
Defined in:
lib/factorix/cli/commands/version.rb

Overview

Display Factorix version

This command outputs the current version of the Factorix gem.

Examples:

$ factorix version
0.1.0

Instance Method Summary collapse

Methods inherited from Base

backup_support!, confirmable!, inherited, require_game_stopped!

Instance Method Details

#callvoid

This method returns an undefined value.

Execute the version command

Outputs the current version of the Factorix gem to stdout.



21
# File 'lib/factorix/cli/commands/version.rb', line 21

def call(**) = out.puts VERSION