Class: Factorix::Runtime::WSL

Inherits:
Windows show all
Defined in:
lib/factorix/runtime/wsl.rb

Overview

WSL (Windows Subsystem for Linux) runtime environment

This implementation inherits from Windows and converts Windows paths to WSL paths. It retrieves Windows environment variables via PowerShell in a single batch operation and converts paths using native Ruby code.

Defined Under Namespace

Classes: WSLPath

Instance Method Summary collapse

Methods inherited from Windows

#data_dir, #executable_path, #user_dir

Methods inherited from Base

#current_log_path, #data_dir, #executable_path, #factorix_cache_dir, #factorix_config_path, #factorix_log_path, inherited, #launch, #lock_path, #mod_dir, #mod_list_path, #mod_settings_path, #player_data_path, #previous_log_path, #running?, #save_dir, #script_output_dir, #user_dir, #xdg_cache_home_dir, #xdg_config_home_dir, #xdg_data_home_dir, #xdg_state_home_dir

Methods included from UserConfigurable

#data_dir, #executable_path, #user_dir

Constructor Details

#initialize(path: WSLPath.new) ⇒ WSL

Initialize WSL runtime environment

Parameters:

  • path (WSLPath) (defaults to: WSLPath.new)

    the path provider (for dependency injection)



17
# File 'lib/factorix/runtime/wsl.rb', line 17

def initialize(path: WSLPath.new) = super