Class: Factorix::CLI::Commands::Version
- Defined in:
- lib/factorix/cli/commands/version.rb
Overview
Display Factorix version
This command outputs the current version of the Factorix gem.
Instance Method Summary collapse
-
#call ⇒ void
Execute the version command.
Methods inherited from Base
backup_support!, confirmable!, inherited, require_game_stopped!
Instance Method Details
#call ⇒ void
This method returns an undefined value.
Execute the version command
Outputs the current version of the Factorix gem to stdout.
21 |
# File 'lib/factorix/cli/commands/version.rb', line 21 def call(**) = out.puts VERSION |